@@ -1,26 +1,26 @@
-/* This source code is a conversion from C to Rust with. The original C code
-  can be found here https://github.com/RJVB/sse_mathfun
-  The intrinsics are documented here: https://software.intel.com/sites/landingpage/IntrinsicsGuide/
-
-  The C code is licensed as follows:
-
-  Copyright (C) 2010,2011  RJVB - extensions
-  Copyright (C) 2007  Julien Pommier
-  This software is provided 'as-is', without any express or implied
-  warranty.  In no event will the authors be held liable for any damages
-  arising from the use of this software.
-  Permission is granted to anyone to use this software for any purpose,
-  including commercial applications, and to alter it and redistribute it
-  freely, subject to the following restrictions:
-  1. The origin of this software must not be misrepresented; you must not
-     claim that you wrote the original software. If you use this software
-     in a product, an acknowledgment in the product documentation would be
-     appreciated but is not required.
-  2. Altered source versions must be plainly marked as such, and must not be
-     misrepresented as being the original software.
-  3. This notice may not be removed or altered from any source distribution.
-  (this is the zlib license)
-*/
+// This source code is a conversion from C to Rust with. The original C code
+// can be found here https://github.com/RJVB/sse_mathfun
+// The intrinsics are documented here: https://software.intel.com/sites/landingpage/IntrinsicsGuide/
+//
+// The C code is licensed as follows:
+//
+// Copyright (C) 2010,2011  RJVB - extensions
+// Copyright (C) 2007  Julien Pommier
+// This software is provided 'as-is', without any express or implied
+// warranty.  In no event will the authors be held liable for any damages
+// arising from the use of this software.
+// Permission is granted to anyone to use this software for any purpose,
+// including commercial applications, and to alter it and redistribute it
+// freely, subject to the following restrictions:
+// 1. The origin of this software must not be misrepresented; you must not
+// claim that you wrote the original software. If you use this software
+// in a product, an acknowledgment in the product documentation would be
+// appreciated but is not required.
+// 2. Altered source versions must be plainly marked as such, and must not be
+// misrepresented as being the original software.
+// 3. This notice may not be removed or altered from any source distribution.
+// (this is the zlib license)
+//
 
 use super::{SimdApproximations, Reg32, IntReg32, UIntReg32, Reg64, IntReg64, UIntReg64};
 #[cfg(feature="use_sse")]
@@ -29,7 +29,7 @@ use simd::x86::sse2::Sse2F64x2;
 use simd::x86::avx::{AvxF64x4, AvxF32x8};
 use std::mem;
 use std::ops::*;
-use numbers::Float;
+use numbers::*;
 use Zero;
 
 macro_rules! simd_approx_impl {
@@ -60,7 +60,7 @@ macro_rules! simd_approx_impl {
                         }
                     };
 
-                 // floating point constants
+                // floating point constants
                 let one = $regf::splat(1.0);
                 let onef_as_uint: $regu = unsafe { mem::transmute(one) };
                 let half = $regf::splat(0.5);
