@@ -1,4 +1,4 @@
 mod real_to_complex;
 pub use self::real_to_complex::*;
-mod real;
-pub use self::real::*;
+mod real_ops;
+pub use self::real_ops::*;
