@@ -1,8 +1,6 @@
 //! This mod contains a definition for window functions and provides implementations for a
 //! few standard windows. See the `WindowFunction` type for more information.
-use RealNumber;
-use std::mem;
-use std;
+use numbers::*;
 
 /// A window function for FFT windows. See `https://en.wikipedia.org/wiki/Window_function`
 /// for details. Window functions should document if they aren't applicable for
@@ -10,17 +8,17 @@ use std;
 ///
 /// The contract for window functions is as follows:
 ///
-/// 1. The second argument is of the function is always `self.points()` and the possible values
-///    for the first argument ranges from `0..self.points()`.
-/// 2. A window function must be symmetric about the y-axis.
-/// 3. All real return values are allowed
+/// 1. The second argument is of the function is always `vector.points()` and the possible values
+///    for the first argument ranges from `0..vector.points()`.
+/// 2. All real return values are allowed
 pub trait WindowFunction<T>: Sync
     where T: RealNumber
 {
-    /// Indicates whether this function is symmetric around 0 or not.
+    /// Indicates whether this function is symmetric around the y axis or not.
     /// Symmetry is defined as `self.window(x) == self.window(-x)`.
     fn is_symmetric(&self) -> bool;
-    /// Calculates a point of the window function
+    
+    /// Calculates a point of the window function. Callers will ensure that `n <= length`.
     fn window(&self, n: usize, length: usize) -> T;
 }
 
@@ -84,62 +82,9 @@ impl<T> WindowFunction<T> for HammingWindow<T>
     }
 }
 
-/// A window function which can be constructed outside this crate.
-#[cfg(feature="std")]
-pub struct ForeignWindowFunction<T>
-    where T: RealNumber
-{
-    /// The window function
-    pub window_function: extern "C" fn(*const std::os::raw::c_void, usize, usize) -> T,
-
-    /// The data which is passed to the window function
-    ///
-    /// Actual data type is a `const* c_void`, but Rust doesn't allow that because it's
-    /// unsafe so we store
-    /// it as `usize` and transmute it when necessary. Callers should make very sure safety
-    /// is guaranteed.
-    pub window_data: usize,
-
-    /// Indicates whether this function is symmetric around 0 or not.
-    /// Symmetry is defined as `self.window(x) == self.window(-x)`.
-    pub is_symmetric: bool,
-}
-
-#[cfg(feature="std")]
-impl<T> ForeignWindowFunction<T>
-    where T: RealNumber
-{
-    /// Creates a new window function
-    pub unsafe fn new(window: extern "C" fn(*const std::os::raw::c_void, usize, usize) -> T,
-               window_data: *const std::os::raw::c_void,
-               is_symmetric: bool)
-               -> Self {
-        ForeignWindowFunction {
-            window_function: window,
-            window_data: mem::transmute(window_data),
-            is_symmetric: is_symmetric,
-        }
-    }
-}
-
-#[cfg(feature="std")]
-impl<T> WindowFunction<T> for ForeignWindowFunction<T>
-    where T: RealNumber
-{
-    fn is_symmetric(&self) -> bool {
-        self.is_symmetric
-    }
-
-    fn window(&self, idx: usize, points: usize) -> T {
-        let fun = self.window_function;
-        fun(self.window_data as *const std::os::raw::c_void, idx, points)
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
-    use super::super::RealNumber;
     use std::fmt::Debug;
 
     fn window_test<T, W>(window: W, expected: &[T])
